@@ -1,12 +1,15 @@
 OC.L10N.register(
     "notes",
     {
+    "Error" : "Fazi",
     "Settings" : "Arventennoù",
     "Today" : "Hiziv",
     "Yesterday" : "Dec'h",
     "Rename" : "Adenvel",
     "Remove from favorites" : "Diverkañañ eus ar pennrolloù",
     "Add to favorites" : "Ouzhpennañ er pennrolloù",
-    "Details" : "Munudoù"
+    "Details" : "Munudoù",
+    "CTRL + /" : "CTRL + /",
+    "Edit" : "Cheñch"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
