@@ -1,13 +1,11 @@
 OC.L10N.register(
     "notes",
     {
-    "The last viewed note cannot be accessed. " : "Ei pääsyä viimeksi katsottuun muistiinpanoon.",
-    "The notes folder is not accessible: %s" : "Ei pääsyä muistiinpanokansioon: %s",
     "Error" : "Virhe",
     "New note" : "Uusi muistiinpano",
     "Notes" : "Muistiinpanot",
-    "Settings" : "Asetukset",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Havaittiin tallentamattomia muistiinpanoja. Sivulta poistuminen hylkää kaikki muutokset!",
+    "Settings" : "Asetukset",
     "Folder to store your notes" : "Kansio johon muistiinpanot tallennetaan",
     "path to notes" : "polku muistiinpanoihin",
     "File extension for new notes" : "Tiedostopääte uusille muistiinpanoille",
@@ -31,8 +29,8 @@ OC.L10N.register(
     "Empty note" : "Tyhjä muistiinpano",
     "Write …" : "Kirjoita…",
     "Details" : "Tiedot",
-    "Preview" : "Esikatselu",
     "Edit" : "Muokkaa",
+    "Preview" : "Esikatselu",
     "Save failed. Click to retry." : "Tallennus epäonnistui. Napsauta yrittääksesi uudelleen.",
     "Set category" : "Aseta luokka",
     "Category" : "Luokka",
