@@ -1,18 +1,15 @@
 OC.L10N.register(
     "notes",
     {
-    "The last viewed note cannot be accessed. " : "אין גישה לפתק האחרון שנצפה.",
-    "The notes folder is not accessible: %s" : "תיקיית הפתקים אינה נגישה: %s",
     "Error" : "שגיאה",
     "New note" : "פתק חדש",
     "Notes" : "הערות",
     "Distraction-free notes and writing" : "פתקים וכתיבה ללא הסחות דעת",
-    "Settings" : "הגדרות",
     "Deleted {title}" : "{title} נמחק",
     "Deleted {number} notes" : "נמחקו {number} פתקים",
     "Undo Delete" : "ביטול מחיקה",
-    "Please chose a valid path in {label} (bottom left corner)." : "נא לבחור נתיב תקני בתוך {label} (פינה ימנית תחתונה).",
     "There are unsaved notes. Leaving the page will discard all changes!" : "ישנן הערות שלא נשמרו. יציאה מהעמוד תעלים את השינויים שערכת!",
+    "Settings" : "הגדרות",
     "Folder to store your notes" : "תיקייה לאחסון הפתקיות שלך",
     "path to notes" : "נתיב לפתקיות",
     "File extension for new notes" : "סיומת קובץ לפתקיות חדשות",
@@ -38,8 +35,8 @@ OC.L10N.register(
     "Empty note" : "פתק ריק",
     "Write …" : "כתיבה…",
     "Details" : "פרטים",
-    "Preview" : "תצוגה מקדימה",
     "Edit" : "עריכה",
+    "Preview" : "תצוגה מקדימה",
     "Exit full screen" : "יציאה ממסך מלא",
     "Full screen" : "מסך מלא",
     "Save failed. Click to retry." : "השמירה נכשלה. יש ללחוץ כדי לנסות שוב.",
