@@ -1,14 +1,12 @@
 OC.L10N.register(
     "notes",
     {
-    "The last viewed note cannot be accessed. " : "Az utoljára megtekintett jegyzet nem elérhető.",
-    "The notes folder is not accessible: %s" : "A jegyzetek mappa nem érhető el: %s",
     "Error" : "Hiba",
     "New note" : "Új jegyzet",
     "Notes" : "Jegyzetek",
     "Distraction-free notes and writing" : "Figyelemelterelés nélküli jegyzetelés és írás",
-    "Settings" : "Beállítások",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Mentetlen jegyzetek vannak. Az oldal elhagyásával a változások elvesznek.",
+    "Settings" : "Beállítások",
     "Folder to store your notes" : "A jegyzetek tárolási mappája",
     "path to notes" : "megjegyzések útvonala",
     "File extension for new notes" : "Fájlkiterjesztés új jegyzetekhez",
@@ -28,8 +26,8 @@ OC.L10N.register(
     "Empty note" : "Üres jegyzet",
     "Write …" : "Írás ...",
     "Details" : "Részletek",
-    "Preview" : "Előnézet",
     "Edit" : "Szerkesztés",
+    "Preview" : "Előnézet",
     "Set category" : "Kategória beállítása",
     "Category" : "Kategória",
     "Uncategorized" : "Kategorizálatlan",
