@@ -1,18 +1,17 @@
 OC.L10N.register(
     "notes",
     {
-    "The last viewed note cannot be accessed. " : "Den senast visade anteckningen kan inte nås.",
-    "The notes folder is not accessible: %s" : "Anteckningsmappen är inte tillgänglig: %s",
+    "Reading notes from filesystem has failed." : "Läsa anteckningar från filsystemet misslyckades.",
     "Error" : "Fel",
     "New note" : "Ny anteckning",
     "Notes" : "Anteckningar",
     "Distraction-free notes and writing" : "Distraktionsfria anteckningar och skrivning",
-    "Settings" : "Inställningar",
+    "Please see Nextcloud server log for details." : "Se Nextcloud serverlogg för mer information.",
     "Deleted {title}" : "Raderad {title}",
     "Deleted {number} notes" : "Raderade {number} anteckningar",
     "Undo Delete" : "Ångra radering",
-    "Please chose a valid path in {label} (bottom left corner)." : "Välj en giltig sökväg i {label} (nedre vänstra hörnet).",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Det finns osparade anteckningar. Lämnas sidan kommer ändringarna förloras!",
+    "Settings" : "Inställningar",
     "Folder to store your notes" : "Mapp för att spara dina anteckningar",
     "path to notes" : "sökväg till anteckningar",
     "File extension for new notes" : "Filtillägg för nya anteckningar",
@@ -38,8 +37,9 @@ OC.L10N.register(
     "Empty note" : "Tom anteckning",
     "Write …" : "Skriv ...",
     "Details" : "Detaljer",
-    "Preview" : "Förhandsvisa",
+    "CTRL + /" : "CTRL + /",
     "Edit" : "Redigera",
+    "Preview" : "Förhandsvisa",
     "Exit full screen" : "Avsluta fullskärm",
     "Full screen" : "Fullskärm",
     "Save failed. Click to retry." : "Kunde inte spara. Klicka för att försöka igen.",
@@ -61,12 +61,19 @@ OC.L10N.register(
     "iOS app" : "iOS-app",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Böja skriva en anteckning genom att klicka på “{newnote}” i menyn.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Du kan skapa underkategorier genom att använda “/” som avgränsare mellan överordnad kategori och underkategori, t.ex. “{parent}/{sub}”.",
+    "Note not found." : "Anteckningen hittades inte.",
+    "Note is locked." : "Anteckningen är låst.",
+    "Insufficient storage." : "Otillräckligt utrymme.",
     "See JavaScript console and server log for details." : "Se JavaScript-konsol och serverlogg för detaljer.",
     "Updating settings has failed." : "Kunde inte uppdatera inställningar. ",
+    "Error from Nextcloud server: {msg}" : "Fel från Nextcloud server: {msg}",
     "Fetching notes has failed." : "Kunde inte hämta anteckningar.",
     "Fetching note {id} has failed." : "Hämtning av anteckning {id} misslyckades.",
+    "Refreshing note {id} has failed." : "Uppdatering av anteckning {id} misslyckades.",
     "Renaming note {id} has failed." : "Namnbyte av anteckning {id} misslyckades.",
     "Creating new note has failed." : "Kunde inte skapa ny anteckning.",
+    "Saving note {id} has failed." : "Spara anteckning {id} misslyckades.",
+    "Updating title for note {id} has failed." : "Uppdatering av titel för anteckning {id} misslyckades.",
     "Undo delete has failed for note {title}." : "Ångra radering misslyckades för anteckning {title}.",
     "Deleting note {id} has failed." : "Radering av anteckning {id} misslyckades.",
     "Toggling favorite for note {id} has failed." : "Växling av favorit för anteckning {id} misslyckades.",
