@@ -1,18 +1,15 @@
 OC.L10N.register(
     "notes",
     {
-    "The last viewed note cannot be accessed. " : "不能访问上次查看的笔记。",
-    "The notes folder is not accessible: %s" : "笔记文件夹无法访问：%s",
     "Error" : "错误",
     "New note" : "新建笔记",
     "Notes" : "笔记",
     "Distraction-free notes and writing" : "无干扰的笔记和写作",
-    "Settings" : "设置",
     "Deleted {title}" : "已删除 {title}",
     "Deleted {number} notes" : "已删除 {number} 条笔记",
     "Undo Delete" : "撤销删除",
-    "Please chose a valid path in {label} (bottom left corner)." : "请在 {label}（左下角）中选择一个有效路径。",
     "There are unsaved notes. Leaving the page will discard all changes!" : "有未保存的记录，离开页面将丢弃所有更改！",
+    "Settings" : "设置",
     "Folder to store your notes" : "保存您的笔记的文件夹",
     "path to notes" : "笔记的路径",
     "File extension for new notes" : "新笔记的文件扩展名",
@@ -37,8 +34,8 @@ OC.L10N.register(
     "Empty note" : "空笔记",
     "Write …" : "编写 ...",
     "Details" : "详细信息",
-    "Preview" : "预览",
     "Edit" : "编辑",
+    "Preview" : "预览",
     "Exit full screen" : "退出全屏",
     "Full screen" : "全屏",
     "Save failed. Click to retry." : "保存失败。点击以重试。",
