@@ -1,4 +1,6 @@
-<?php declare(strict_types=1);
+<?php
+
+declare(strict_types=1);
 
 namespace OCA\Notes\Controller;
 
@@ -8,7 +10,6 @@ use OCP\AppFramework\Http\ContentSecurityPolicy;
 use OCP\IRequest;
 
 class PageController extends Controller {
-
 	public function __construct(string $AppName, IRequest $request) {
 		parent::__construct($AppName, $request);
 	}
@@ -21,7 +22,7 @@ class PageController extends Controller {
 	 * @return TemplateResponse
 	 */
 	public function index() : TemplateResponse {
-		$devMode = !is_file(dirname(__FILE__).'/../../js/notes.js');
+		$devMode = !is_file(dirname(__FILE__).'/../../js/notes-main.js');
 		$response = new TemplateResponse(
 			$this->appName,
 			$devMode ? 'dev-mode' : 'main',
