@@ -1,4 +1,6 @@
-<?php declare(strict_types=1);
+<?php
+
+declare(strict_types=1);
 
 namespace OCA\Notes\Service;
 
@@ -47,7 +49,6 @@ use OCA\Notes\Db\MetaMapper;
  * with this approach! :-)
  */
 class MetaService {
-
 	private $metaMapper;
 
 	public function __construct(MetaMapper $metaMapper) {
@@ -105,7 +106,7 @@ class MetaService {
 	private function getIndexedArray(array $data, string $property) : array {
 		$property = ucfirst($property);
 		$getter = 'get'.$property;
-		$result = array();
+		$result = [];
 		foreach ($data as $entity) {
 			$result[$entity->$getter()] = $entity;
 		}
@@ -154,7 +155,9 @@ class MetaService {
 
 	// warning: this is expensive
 	private function generateContentEtag(Note $note) : string {
-		return md5($note->getContent());
+		return Util::retryIfLocked(function () use ($note) {
+			return md5($note->getContent());
+		}, 3);
 	}
 
 	// this is not expensive, since we use the content ETag instead of the content itself
